summaryrefslogtreecommitdiffstats
path: root/kdeui/knumvalidator.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdeui/knumvalidator.h')
-rw-r--r--kdeui/knumvalidator.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/kdeui/knumvalidator.h b/kdeui/knumvalidator.h
index 114a82d57..55711fadb 100644
--- a/kdeui/knumvalidator.h
+++ b/kdeui/knumvalidator.h
@@ -24,7 +24,7 @@
#ifndef __KNUMVALIDATOR_H
#define __KNUMVALIDATOR_H
-#include <qvalidator.h>
+#include <tqvalidator.h>
#include <kdelibs_export.h>
@@ -32,26 +32,26 @@ class QWidget;
class QString;
/**
- * QValidator for integers.
+ * TQValidator for integers.
- This can be used by QLineEdit or subclass to provide validated
+ This can be used by TQLineEdit or subclass to provide validated
text entry. Can be provided with a base value (default is 10), to allow
the proper entry of hexadecimal, octal, or any other base numeric data.
@author Glen Parker <glenebob@nwlink.com>
@version 0.0.1
*/
-class KDEUI_EXPORT KIntValidator : public QValidator {
+class KDEUI_EXPORT KIntValidator : public TQValidator {
public:
/**
Constuctor. Also sets the base value.
*/
- KIntValidator ( QWidget * parent, int base = 10, const char * name = 0 );
+ KIntValidator ( TQWidget * parent, int base = 10, const char * name = 0 );
/**
* Constructor. Also sets the minimum, maximum, and numeric base values.
*/
- KIntValidator ( int bottom, int top, QWidget * parent, int base = 10, const char * name = 0 );
+ KIntValidator ( int bottom, int top, TQWidget * parent, int base = 10, const char * name = 0 );
/**
* Destructs the validator.
*/
@@ -59,11 +59,11 @@ class KDEUI_EXPORT KIntValidator : public QValidator {
/**
* Validates the text, and return the result. Does not modify the parameters.
*/
- virtual State validate ( QString &, int & ) const;
+ virtual State validate ( TQString &, int & ) const;
/**
* Fixes the text if possible, providing a valid string. The parameter may be modified.
*/
- virtual void fixup ( QString & ) const;
+ virtual void fixup ( TQString & ) const;
/**
* Sets the minimum and maximum values allowed.
*/
@@ -95,32 +95,32 @@ class KDEUI_EXPORT KIntValidator : public QValidator {
class KFloatValidatorPrivate;
/**
- \brief QValidator for floating point entry (Obsolete)
+ \brief TQValidator for floating point entry (Obsolete)
@obsolete Use KDoubleValidator
- Extends the QValidator class to properly validate double numeric data.
- This can be used by QLineEdit or subclass to provide validated
+ Extends the TQValidator class to properly validate double numeric data.
+ This can be used by TQLineEdit or subclass to provide validated
text entry.
@author Glen Parker <glenebob@nwlink.com>
@version 0.0.1
*/
-class KDEUI_EXPORT KFloatValidator : public QValidator {
+class KDEUI_EXPORT KFloatValidator : public TQValidator {
public:
/**
* Constructor.
*/
- KFloatValidator ( QWidget * parent, const char * name = 0 );
+ KFloatValidator ( TQWidget * parent, const char * name = 0 );
/**
* Constructor. Also sets the minimum and maximum values.
*/
- KFloatValidator ( double bottom, double top, QWidget * parent, const char * name = 0 );
+ KFloatValidator ( double bottom, double top, TQWidget * parent, const char * name = 0 );
/**
* Constructor. Sets the validator to be locale aware if @p localeAware is true.
*/
- KFloatValidator ( double bottom, double top, bool localeAware, QWidget * parent, const char * name = 0 );
+ KFloatValidator ( double bottom, double top, bool localeAware, TQWidget * parent, const char * name = 0 );
/**
* Destructs the validator.
*/
@@ -128,11 +128,11 @@ class KDEUI_EXPORT KFloatValidator : public QValidator {
/**
* Validates the text, and return the result. Does not modify the parameters.
*/
- virtual State validate ( QString &, int & ) const;
+ virtual State validate ( TQString &, int & ) const;
/**
* Fixes the text if possible, providing a valid string. The parameter may be modified.
*/
- virtual void fixup ( QString & ) const;
+ virtual void fixup ( TQString & ) const;
/**
* Sets the minimum and maximum value allowed.
*/
@@ -167,7 +167,7 @@ class KDEUI_EXPORT KFloatValidator : public QValidator {
/**
@short A locale-aware QDoubleValidator
- KDoubleValidator extends QDoubleValidator to be
+ KDoubleValidator extends TQDoubleValidator to be
locale-aware. That means that - subject to not being disabled -
KLocale::decimalSymbol(), KLocale::thousandsSeparator()
and KLocale::positiveSign() and KLocale::negativeSign()
@@ -178,25 +178,25 @@ class KDEUI_EXPORT KFloatValidator : public QValidator {
@since 3.1
**/
-class KDEUI_EXPORT KDoubleValidator : public QDoubleValidator {
+class KDEUI_EXPORT KDoubleValidator : public TQDoubleValidator {
Q_OBJECT
Q_PROPERTY( bool acceptLocalizedNumbers READ acceptLocalizedNumbers WRITE setAcceptLocalizedNumbers )
public:
/** Constuct a locale-aware KDoubleValidator with default range
- (whatever QDoubleValidator uses for that) and parent @p
+ (whatever TQDoubleValidator uses for that) and parent @p
parent */
- KDoubleValidator( QObject * parent, const char * name=0 );
+ KDoubleValidator( TQObject * parent, const char * name=0 );
/** Constuct a locale-aware KDoubleValidator for range [@p bottom,@p
top] and a precision of @p decimals decimals after the decimal
point. */
KDoubleValidator( double bottom, double top, int decimals,
- QObject * parent, const char * name=0 );
+ TQObject * parent, const char * name=0 );
/** Destructs the validator.
*/
virtual ~KDoubleValidator();
/** Overloaded for internal reasons. The API is not affected. */
- virtual QValidator::State validate( QString & input, int & pos ) const;
+ virtual TQValidator::State validate( TQString & input, int & pos ) const;
/** @return whether localized numbers are accepted (default: true) */
bool acceptLocalizedNumbers() const;
@@ -204,7 +204,7 @@ public:
void setAcceptLocalizedNumbers( bool accept );
private:
- typedef QDoubleValidator base;
+ typedef TQDoubleValidator base;
class Private;
Private * d;
};